package com.ff.common.mapper;

import java.util.List;
import com.ff.common.domain.TenantSecretKey;

/**
 * 用户租户密钥Mapper接口
 * 
 * @author shi
 * @date 2025-02-11
 */
public interface TenantSecretKeyMapper 
{
    /**
     * 查询用户租户密钥
     * 
     * @param id 用户租户密钥主键
     * @return 用户租户密钥
     */
     TenantSecretKey selectTenantSecretKeyById(Long id);

    /**
     * 按租户密钥选择租户密钥
     *
     * @param tenantKey 租户密钥
     * @return {@link TenantSecretKey }
     */
    TenantSecretKey selectTenantSecretKeyByTenantKey(String tenantKey);

    /**
     * 查询用户租户密钥列表
     * 
     * @param tenantSecretKey 用户租户密钥
     * @return 用户租户密钥集合
     */
     List<TenantSecretKey> selectTenantSecretKeyList(TenantSecretKey tenantSecretKey);

    /**
     * 新增用户租户密钥
     * 
     * @param tenantSecretKey 用户租户密钥
     * @return 结果
     */
     int insertTenantSecretKey(TenantSecretKey tenantSecretKey);

    /**
     * 修改用户租户密钥
     * 
     * @param tenantSecretKey 用户租户密钥
     * @return 结果
     */
     int updateTenantSecretKey(TenantSecretKey tenantSecretKey);

    /**
     * 删除用户租户密钥
     * 
     * @param id 用户租户密钥主键
     * @return 结果
     */
     int deleteTenantSecretKeyById(Long id);

    /**
     * 批量删除用户租户密钥
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteTenantSecretKeyByIds(Long[] ids);
}
